==> rdblib-2.5.6-arm-linux.tar.gz: rdblib-2.5.6-arm-linux/interface/cpp/riegl/rdb/version.cpp <==
/*
 *******************************************************************************
 *
 *  Copyright 2025 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 */
/*!
 *******************************************************************************
 *
 * \file    version.cpp
 * \author  RIEGL LMS GmbH, Austria
 * \brief   RDB library API version
 * \version 2020-01-16/AW: Initial version
 *
 *******************************************************************************
 */

//---< INCLUDES >---------------------------------------------------------------

#include "riegl/rdb/version.hpp"

//---< NAMESPACE >--------------------------------------------------------------

namespace riegl {
namespace rdb {

const std::string& interfaceName()
{
    static const std::string name("RDB Interface");
    return name;
}

const std::string& interfaceVersion()
{
    static const std::string version("2.5.6-a3f98410 (C++, Sep 10 2025, 14:38:55)");
    return version;
}

}} // namespace riegl::rdb

==> rdblib-2.5.7-arm-linux.tar.gz: rdblib-2.5.7-arm-linux/interface/cpp/riegl/rdb/version.cpp <==
/*
 *******************************************************************************
 *
 *  Copyright 2025 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 */
/*!
 *******************************************************************************
 *
 * \file    version.cpp
 * \author  RIEGL LMS GmbH, Austria
 * \brief   RDB library API version
 * \version 2020-01-16/AW: Initial version
 *
 *******************************************************************************
 */

//---< INCLUDES >---------------------------------------------------------------

#include "riegl/rdb/version.hpp"

//---< NAMESPACE >--------------------------------------------------------------

namespace riegl {
namespace rdb {

const std::string& interfaceName()
{
    static const std::string name("RDB Interface");
    return name;
}

const std::string& interfaceVersion()
{
    static const std::string version("2.5.7-0bbe6e0f (C++, Nov 21 2025, 13:57:18)");
    return version;
}

}} // namespace riegl::rdb
